@@ -8,7 +8,7 @@
 {-# LANGUAGE PatternGuards #-}
 {-# LANGUAGE Rank2Types #-}
 {-# LANGUAGE ScopedTypeVariables #-}
-#if defined(__GLASGOW_HASKELL__) && __GLASGOW_HASKELL__ >= 706
+#if __GLASGOW_HASKELL__ >= 706
 {-# LANGUAGE DataKinds #-}
 {-# LANGUAGE PolyKinds #-}
 {-# LANGUAGE TypeOperators #-}
@@ -23,8 +23,6 @@
 # endif
 #endif
 
-{-# OPTIONS_GHC -fno-warn-orphans #-}
-
 {-# LANGUAGE TypeFamilies #-}
 {-# LANGUAGE DeriveDataTypeable #-}
 {-# LANGUAGE UndecidableInstances #-}
@@ -32,6 +30,7 @@
 {-# OPTIONS_GHC -fno-cse #-}
 {-# OPTIONS_GHC -fno-full-laziness #-}
 {-# OPTIONS_GHC -fno-float-in #-}
+{-# OPTIONS_GHC -fno-warn-orphans #-}
 {-# OPTIONS_GHC -fno-warn-unused-binds #-}
 
 #ifndef MIN_VERSION_base
@@ -118,9 +117,9 @@ import Data.Bits
 
 #if __GLASGOW_HASKELL__ < 710
 import Data.Foldable
-import Data.Monoid
 #endif
 
+import Data.Semigroup as Sem
 import Data.Proxy
 
 #if __GLASGOW_HASKELL__ < 710
@@ -132,7 +131,7 @@ import Data.Word
 import Foreign.Ptr
 import Foreign.StablePtr
 
-#if (defined(__GLASGOW_HASKELL__) && __GLASGOW_HASKELL__ >= 707) || (defined(MIN_VERSION_template_haskell) && USE_TYPE_LITS)
+#if (__GLASGOW_HASKELL__ >= 707) || (defined(MIN_VERSION_template_haskell) && USE_TYPE_LITS)
 import GHC.TypeLits
 #endif
 
@@ -358,7 +357,7 @@ onProxyType1 f
     | proxyName == ''Proxy = ConE 'Proxy `SigE` (ConT ''Proxy `AppT` f ta)
 onProxyType1 f a =
         LamE [SigP WildP na] body `AppE` a
-    where 
+    where
           body = ConE 'Proxy `SigE` (ConT ''Proxy `AppT` f na)
           na = VarT (mkName "na")
 
@@ -553,8 +552,13 @@ reifyTypeable a k = unsafePerformIO $ do
 
 data ReifiedMonoid a = ReifiedMonoid { reifiedMappend :: a -> a -> a, reifiedMempty :: a }
 
+instance Reifies s (ReifiedMonoid a) => Sem.Semigroup (ReflectedMonoid a s) where
+  ReflectedMonoid x <> ReflectedMonoid y = reflectResult (\m -> ReflectedMonoid (reifiedMappend m x y))
+
 instance Reifies s (ReifiedMonoid a) => Monoid (ReflectedMonoid a s) where
-  mappend (ReflectedMonoid x) (ReflectedMonoid y) = reflectResult (\m -> ReflectedMonoid (reifiedMappend m x y))
+#if !(MIN_VERSION_base(4,11,0))
+  mappend = (<>)
+#endif
   mempty = reflectResult (\m -> ReflectedMonoid (reifiedMempty  m    ))
 
 reflectResult :: forall f s a. Reifies s a => (a -> f s) -> f s
